
==========================
Leonardo leonardo-hijack
==========================

Leonardo module which wrapps django-hijack allows superusers to hijack (=login as) and work on behalf of other users without knowing their credentials.

.. contents::
    :local:

Installation
------------

.. code-block:: bash

    pip install leonardo-hijack

Read More
=========

* https://github.com/django-leonardo/django-leonardo
* https://github.com/arteria/django-hijack